
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#include <vector>
#include <pappsomspp/types.h>
#include "proteinxtp.h"
#include "peptidematch.h"
#include "automaticfilterparameters.h"
#include "../grouping/groupingexperiment.h"
#include "../utils/groupstore.h"
#include "../grouping/groupinggroup.h"

#ifndef PROTEINMATCH_H
#define PROTEINMATCH_H

class IdentificationGroup;

class ProteinMatch
{
  friend IdentificationGroup;
public:
    ProteinMatch();
    ~ProteinMatch();

    const ProteinXtpSp & getProteinXtpSp() const;
    void setEvalue(pappso::pappso_double evalue);
    pappso::pappso_double getEvalue() const;
    pappso::pappso_double getCoverage() const;
    void setProteinXtpSp(ProteinXtpSp protein_sp);
    void addPeptideMatch(PeptideMatch * peptide_match);
    std::vector<PeptideMatch *> & getPeptideMatchList();
    const std::vector<PeptideMatch *> & getPeptideMatchList() const;
    void setChecked(bool arg1);

    bool isChecked() const;
    bool isValid() const;
    bool isValidAndChecked() const;

    /** @brief count valid spectrums
     * */
    size_t countValidSpectrum()const;

    /** @brief count valid and manually checked spectrums
     * */
    size_t countValidAndCheckedSpectrum()const;
    /** @brief count unique identified sequences (from valid and cheked spectrums)
     * */
    size_t countUniqueSequence()const;


    const pappso::GrpProteinSp & getGrpProteinSp() const;
    const GroupingGroupSp & getGroupingGroupSp() const;
    
protected :
 
    /** @brief validate or invalidate peptides and proteins based automatic filters and manual checks
    * */
    void updateAutomaticFilters(const AutomaticFilterParameters & automatic_filter_parameters);

    void setGroupingExperiment(GroupingExperiment * p_grp_experiment);
 
    void setGroupInstance(GroupStore & group_store);

private:
    pappso::GrpProteinSp _sp_grp_protein;
    GroupingGroupSp _sp_group;

    std::vector<PeptideMatch *> _peptide_match_list;
    ProteinXtpSp _protein_sp = nullptr;
    pappso::pappso_double _evalue=0;
    /** @brief manually checked by user (true by default)
     */
    bool _checked = true;

    /** @brief automatic filter result (false by default)
     */
    bool _proxy_valid = false;

};

#endif // PROTEINMATCH_H
