
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#ifndef PROJECTWINDOW_H
#define PROJECTWINDOW_H

#include <QMainWindow>
#include "../../core/project.h"
#include "../protein_list_view/proteinlistwindow.h"
#include "../peptide_list_view/peptidelistwindow.h"

class MainWindow;

//http://doc.qt.io/qt-4.8/qt-itemviews-chart-mainwindow-cpp.html
namespace Ui {
class ProjectView;
}

class ProjectWindow: public QMainWindow {
    Q_OBJECT

public:

    explicit ProjectWindow(MainWindow * parent = 0);
    void setProjectSp(ProjectSp project_sp);
    ~ProjectWindow();

public slots:
    void doViewProteinList(IdentificationGroup* p_identification_group =nullptr);
    void doViewPeptideList(ProteinMatch * protein_match);
    void doIdentificationGroupEdited(IdentificationGroup * p_identification_group);
    void setDefaultProteinListWindow(ProteinListWindow* p_protein_list_window);
    // void setColor(const QColor &color);
    // void setShape(Shape shape);
signals:
    void identificationGroupGrouped(IdentificationGroup * p_identification_group);
    //void peptideChanged(pappso::PeptideSp peptide);

private :
    void connectNewProteinListWindow();
    void connectNewPeptideListWindow();
private:
    Ui::ProjectView *ui;
    MainWindow * main_window;
    std::list <ProteinListWindow *> _protein_list_window_collection;
    ProteinListWindow * _p_current_protein_list_window = nullptr;
    std::list <PeptideListWindow *> _peptide_list_window_collection;
    PeptideListWindow * _p_current_peptide_list_window = nullptr;
    ProjectSp _project_sp;


};


#endif // PROJECTWINDOW_H
